function f_xyz=fct3D(x,y,z,function_type)

%--------------------------------------------------------------------------
% FUNCTION DEFINITION.
%--------------------------------------------------------------------------
% INPUTS.
%---------
%
% x,y,z: EVALUATE THE FUNCTION IN THE POINTS (x,y,z). "x", "y", "z" ARE 
%        COLUMN VECTORS.
%
% function_type: PARAMETER THAT CHOOSES THE FUNCTION.
%
%----------
% OUTPUTS.
%----------
%
% f_xyz: VALUE OF THE FUNCTION IN THE POINTS (x,y,z). IT IS A COLUMN VECTOR.
%
%--------------------------------------------------------------------------

%--------------------------------------------------------------------------
%% Copyright (C) 2007-2009 Alvise Sommariva, Marco Vianello.
%%
%% This program is free software; you can redistribute it and/or modify
%% it under the terms of the GNU General Public License as published by
%% the Free Software Foundation; either version 2 of the License, or
%% (at your option) any later version.
%%
%% This program is distributed in the hope that it will be useful,
%% but WITHOUT ANY WARRANTY; without even the implied warranty of
%% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%% GNU General Public License for more details.
%%
%% You should have received a copy of the GNU General Public License
%% along with this program; if not, write to the Free Software
%% Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
%%
%% Author:  Marco Caliari     <marco.caliari@univr.it>
%%          Stefano De Marchi <stefano.demarchi@univr.it>
%%          Alvise Sommariva  <alvise@math.unipd.it>
%%          Marco Vianello    <marcov@math.unipd.it>
%%
%% Date: February 28, 2010.
%--------------------------------------------------------------------------

switch function_type
    
    case 1
        f_xyz=((x-0.4).^2+(y-0.4).^2+(z-0.4).^2).^(1/2);
        
    case 2
        f_xyz = ((x-0.5).^2+(y-0.5).^2+(z-0.5).^2).^(1/2);
        
    case 3
        f_xyz = (x+y+z).^20;
        
    case 4
        loc_arg = (x-0.5).^2+(y-0.5).^2+(z-0.5).^2;
        f_xyz = exp(loc_arg);
        
    case 5
        loc_arg = (x-0.5).^2+(y-0.5).^2+(z-0.5).^2;
        f_xyz = exp(-100*loc_arg);
        
    case 6
        f_xyz = cos(30*(x+y+z));
        
    case 7
        f_xyz = ones(size(x));
        
    case 8
        f_xyz = exp(x+y+z);
        
    case 9
        den = 1+16*(x.^2+y.^2+z.^2);
        f_xyz = 1./den;
        
    case 10
        f_xyz = (x.^2+y.^2+z.^2).^(3/2);
        
    case 11
        f_xyz = exp(-x.^2-y.^2-z.^2);
        
    case 12
        arg_z = (x.^2+y.^2+z.^2);
        % Avoid cases in which "arg_z=0", setting only in those instances
        % "arg_z=eps".
        arg_z = arg_z+(1-abs(sign(arg_z)))*eps;
        arg_z = 1./arg_z;
        f_xyz = exp(-arg_z);
        
    case 13
        f_xyz=cos(x.^2+y.^2+z.^2);
        
    case 14
        f_xyz=cos(x+y+z);
        
    case 15
        f_xyz=(x.^2+y+x.*z);
        
        
end


