
function [nodes_x,nodes_y,nodes_z,parallelepiped]=wam3D(M,wam_select)

%--------------------------------------------------------------------------
% OBJECT:
%----------
%
% THIS ROUTINE DEFINES CERTAIN WAMS ON 3D DOMAINS.
%
%---------
% INPUT.
%---------
%
% M : DEGREE OF THE VANDERMONDE BASIS.
%
% wam_select: SPECIFIES THE 3D DOMAIN.
%
%             1: UNIT BALL.
%             2: THETRAEDRA.
%             3. CUBE. TENSORIAL GAUSS LEGENDRE.
%
%----------
% OUTPUT.
%----------
%
% nodes_x,nodes_y,nodes_z: x,y COMPONENTS OF WAM POINTS.
%
% parallelepiped: SMALLEST PARALLELEPIPED WITH SIDES PARALLEL TO THE x,y,z
%               AXIS THAT CONTAINS THE nodes.
%
%--------------------------------------------------------------------------
%--------------------------------------------------------------------------
%% Copyright (C) 2010 Alvise Sommariva, Marco Vianello.
%%
%% This program is free software; you can redistribute it and/or modify
%% it under the terms of the GNU General Public License as published by
%% the Free Software Foundation; either version 2 of the License, or
%% (at your option) any later version.
%%
%% This program is distributed in the hope that it will be useful,
%% but WITHOUT ANY WARRANTY; without even the implied warranty of
%% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%% GNU General Public License for more details.
%%
%% You should have received a copy of the GNU General Public License
%% along with this program; if not, write to the Free Software
%% Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
%%
%% Authors: Giordano Orzetti
%%          Alvise Sommariva <alvise@euler.math.unipd.it>
%%          Marco Vianello   <marcov@euler.math.unipd.it>
%%
%% Date: February 28, 2010
%--------------------------------------------------------------------------

switch wam_select

    case 1 % UNIT BALL (BY GIORDANO ORZETTI).
        n=M;
        n2 = n/2;
        
        t=[]; 
        iindex = 0;
        
        for l=0:n+1
            pl=(l*pi)/(n+2);
            for k=1:n+1
                tk = (k*pi)/(n+2);
                for j=0:(n2-1)
                    rj = cos((j*pi)/(n)) ;
                    t=[t; rj*sin(tk)*cos(pl) rj*sin(tk)*sin(pl) rj*cos(tk)];
                    iindex = iindex+1;
                end
                for j=(n2+1):n
                    rj = cos((j*pi)/(n)) ;
                    t=[t; rj*sin(tk)*cos(pl) rj*sin(tk)*sin(pl) rj*cos(tk)];
                    iindex = iindex+1;
                end
            end
        end
        
        for j = 0:n
            rj = cos((j*pi)/(n)) ;
            t=[t; 0 0 rj];
        end

        nodes_x=t(:,1);
        nodes_y=t(:,2);
        nodes_z=t(:,3);

      %  weights=ones(size(nodes_x))/length(nodes_x);
        
        parallelepiped=[-1 1 -1 1 -1 1];

    case 2 % THETRAEDRA (BY GIORDANO ORZETTI).
        
        n=M;
        t=[];
        iindex = 0;
        
        for l=0:n
            pl=(l*pi)/(2*n);
            for k=1:n
                tk = (k*pi)/(2*n);
                for j=0:(n-1)
                    rj = cos((j*pi)/(2*n));
                    t=[t; (rj*sin(tk)*cos(pl))^2 ...
                        (rj*sin(tk)*sin(pl))^2 (rj*cos(tk))^2];
                    iindex = iindex+1;
                end
            end
        end
        
        for j = 0:n
            rj = cos((j*pi)/(2*n)) ;
            t=[t; 0 0 rj];
        end

        nodes_x=t(:,1);
        nodes_y=t(:,2);
        nodes_z=t(:,3);

       % weights=ones(size(nodes_x))/length(nodes_x);

        parallelepiped=[0 1 0 1 0 1];
        
    case 3 % UNIT CUBE: [-1,1] x [-1,1] x [-1,1]. TENS. GAUSS-LEGENDRE.
        
        n=M;
        [nodes1D,weights1D]=quadrature_rules_1D(n,4);
        [nodes_x,nodes_y,nodes_z]=meshgrid(nodes1D,nodes1D,nodes1D);
        
        nodes_x=nodes_x(:);
        nodes_y=nodes_y(:);
        nodes_z=nodes_z(:);
        
    case 4 % UNIT CUBE: [-1,1] x [-1,1] x [-1,1]. TENS.PD-GAUSS-LEGENDRE.
        
        n=M;
        Pad = pdpts(n);
        [nodes1D,weights1D]=quadrature_rules_1D(n,4);
        [nodes_x,nodes_y,nodes_z]=meshgrid(Pad(:,1),Pad(:,2),nodes1D);
        
        nodes_x=nodes_x(:);
        nodes_y=nodes_y(:);
        nodes_z=nodes_z(:);
        
end






